summaryrefslogtreecommitdiffstats
path: root/kcron/ktprint.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kcron/ktprint.cpp')
-rw-r--r--kcron/ktprint.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kcron/ktprint.cpp b/kcron/ktprint.cpp
index b1de5c6..ceb1482 100644
--- a/kcron/ktprint.cpp
+++ b/kcron/ktprint.cpp
@@ -104,7 +104,7 @@ TQFont KTPrint :: getFont () const
return paint->font();
}
-void KTPrint :: print (const TQString &str, int col, int alignment, bool wordWrap)
+void KTPrint :: print (const TQString &str, int col, int tqalignment, bool wordWrap)
{
//Prints the string str into the column col using
//the remaining arguments as format flags
@@ -115,8 +115,8 @@ void KTPrint :: print (const TQString &str, int col, int alignment, bool wordWra
return;
- //Setup the alignment
- switch (alignment) {
+ //Setup the tqalignment
+ switch (tqalignment) {
case alignTextLeft : format = AlignLeft | AlignTop | DontClip | ExpandTabs; break;
case alignTextCenter : format = AlignHCenter | AlignTop | DontClip | ExpandTabs; break;
case alignTextRight : format = AlignRight | AlignTop | DontClip | ExpandTabs; break;